# FiPy Solver Benchmarking

2022-08-31T13:00:00-04:00

## Attendees:

- Daniel Wheeler
- Trevor Keller
- me

## Suggestions/Questions:

- is pysparse faster because of building fast or solving fast

- fraction of solve time for diffusion problem

- add convection term
    - binary phase field with frozen composition?
    - no, frozen phase leaves convection-diffusion equation for solute

- compare a pysparse line to one of the slow ones by profiling

- number of iterations, solve time, matrix population time
